@@ -1,22 +1,21 @@
 #' @title Add identifier to columns
 #'
 #' @description Add a prefixed identifier to the first column of the dataset.
-#' @inheritParams dataset
+#' @param x A dataset created with \code{\link{dataset_df}}.
 #' @param prefix Defaults to \code{eg:} (example.com).
 #' @param ids Defaults to \code{NULL}.
 #' @return A dataset conforming the original sub-class of \code{x}.
 #' @examples
 #'
-#' # Example with a dataaset object:
+#' # Example with a dataset_df object:
 #' id_to_column(iris_dataset)
 #'
-#' # Example with a data.frame object:
-#'
+#' # Example with a data.frame object:#'
 #' id_to_column(iris, prefix="eg:iris-o")
 #' @export
 id_to_column <- function(x, prefix = "eg:", ids = NULL) {
 
-  is_dataset <- is.dataset(x)
+  is_dataset <- is.dataset_df(x)
 
   lastcol <- ncol(x)
 
@@ -34,19 +33,12 @@ id_to_column <- function(x, prefix = "eg:", ids = NULL) {
 
   if (is_dataset) {
 
-    DataBibentry <- dataset_bibentry(rhs)
-    tmp <- dataset(cbind(lhs, rhs),
-                   author=DataBibentry$author,
-                   title = DataBibentry$title)
-
-    if (nrow(tmp)>0) {
-      row.names(tmp) <- 1:nrow(tmp)
-    } else {
-      row.names(tmp) <- NULL
-    }
-
-    attr(tmp, "DataBibentry") <-  DataBibentry
-
+    DataBibentry <- get_bibentry(rhs)
+    tmp <- as_dataset_df(cbind(lhs, rhs),
+                      reference = list(author=DataBibentry$author,
+                                     title = DataBibentry$title)
+                      )
+    attr(tmp, "dataset_bibentry") <-  DataBibentry
   } else {
     tmp <- cbind(lhs, rhs)
   }
