@@ -4,13 +4,14 @@
 #' @details \code{Rights} corresponds to
 #' \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/rights/}{dct:rights} and
 #' \code{\link{datacite}} Rights. Information about rights held in and over the resource.
-#' Typically, rights information includes a statement about various property rights associated with the resource,
-#' including intellectual property rights.
-#' @param x A dataset object created with \code{dataset::\link{dataset}}.
+#' Typically, rights information includes a statement about various property
+#' rights associated with the resource, including intellectual property rights.
+#' @param x A semantically rich data frame object created by  \code{dataset::\link{dataset_df}} or
+#'  \code{dataset::\link{as_dataset_df}}.
 #' @param value The \code{Rights} as a character set.
-#' @param overwrite If the \code{Rights} attribute should be overwritten. In case it is set to \code{FALSE},
-#' it gives a message with the current \code{Rights} property instead of overwriting it.
-#' Defaults to \code{FALSE}.
+#' @param overwrite If the \code{Rights} attribute should be overwritten. In case it
+#' is set to \code{FALSE}, it gives a message with the current \code{Rights}
+#' property instead of overwriting it. Defaults to \code{FALSE}.
 #' @return The \code{Rights} attribute as a character of length 1 is added to \code{x}.
 #' @examples
 #' rights(iris_dataset) <- "CC-BY-SA"
@@ -18,10 +19,10 @@
 #' @family Reference metadata functions
 #' @export
 rights <- function(x) {
-  assertthat::assert_that(is.dataset(x),
-                          msg = "rights(x): x must be a dataset object created with dataset() or as_dataset().")
+  assertthat::assert_that(is.dataset_df(x),
+                          msg = "rights(x): x must be a dataset object created with dataset_df() or as_dataset_df().")
 
-  DataBibentry <- dataset_bibentry(x)
+  DataBibentry <- get_bibentry(x)
   as.character(DataBibentry$rights)
 
 }
@@ -30,14 +31,14 @@ rights <- function(x) {
 #' @export
 `rights<-` <- function(x,  overwrite = FALSE, value) {
 
-  assertthat::assert_that(is.dataset(x),
-                          msg = "rights(x): x must be a dataset object created with dataset() or as_dataset().")
+  assertthat::assert_that(is.dataset_df(x),
+                          msg = "rights(x): x must be a dataset object created with dataset_f() or as_dataset_df().")
 
-  DataBibentry <- invisible(dataset_bibentry(x))
+  DataBibentry <- invisible(get_bibentry(x))
 
   if ( is.null(value) ) {
     DataBibentry$rights <- ":unas"
-    attr(x, "DataBibentry") <- DataBibentry
+    attr(x, "dataset_bibentry") <- DataBibentry
     return(invisible(x))
   }
 
@@ -57,6 +58,6 @@ rights <- function(x) {
     message ("The dataset has already a rights field: ",    DataBibentry$rights )
   }
 
-  attr(x, "DataBibentry") <- DataBibentry
+  attr(x, "attribtes_bibentry") <- DataBibentry
   invisible(x)
 }
