@@ -1,26 +1,42 @@
 #' @title Create/add/retrieve a subject
-#' @param x A dataset object created with \code{dataset::\link{dataset}}.
+#' @details
+#' The subject class and its function record the subject property of the dataset.
+#' The DataCite definition allows the use of multiple subproperties, however, these
+#' cannot be added to the standard \code{\link[utils:bibentry]{utils::bibentry}}
+#' object. Therefore, if the user sets the value of the subject field to a
+#' character string, it is added to the bibentry of the dataset, and also to
+#' a separate \code{subject} attribute. If the user wants to use the more detailed
+#' subproperties (see examples with \code{subject_create}), then the subject$term
+#' value is added to the bibentry as a text, and the more complex subject object
+#' is added as a separate attribute to the dataset_df object.#'
+#' @param x A dataset object created with \code{\link{dataset_df}} or
+#' \code{dataset::\link{as_dataset_df}}.
 #' @examples
-#' subject(iris_dataset,
-#'         overwrite = TRUE) <- subject_create(
-#'                                   term  = "Irises (plants)",
-#'                                   schemeURI = "http://id.loc.gov/authorities/subjects",
-#'                                   valueURI = "https://id.loc.gov/authorities/subjects/sh85068079",
-#'                                   subjectScheme = "LCCH",
-#'                                   prefix = "lcch:")
+#' # To set the subject of a dataset_df object:
+#' subject(iris_dataset) <- subject_create(
+#'          term  = "Irises (plants)",
+#'          schemeURI = "http://id.loc.gov/authorities/subjects",
+#'          valueURI = "https://id.loc.gov/authorities/subjects/sh85068079",
+#'          subjectScheme = "LCCH",
+#'          prefix = "lcch:")
+#'
+#' # To retrieve the subject with its subproperties:
 #' subject(iris_dataset)
 #' @export
+#' @return \code{subject(x)} returns the subject attribute of the
+#' \code{\link{dataset_df}} object \code{x}, \code{subject(x)<-value} sets
+#' the same attribute to \code{value} and invisibly returns the \code{x} object with
+#' the changed attributes.
+#' @importFrom assertthat assert_that
 #' @rdname subject
-
-#' @return The Subject field of the dataset's attributes.
 subject <- function(x) {
-  assert_that(is.dataset(x),
-              msg = "subject(x): x must be a dataset object created with dataset() or as_dataset().")
+  assertthat::assert_that(is.dataset_df(x),
+              msg = "subject(x): x must be a dataset_df object created with dataset_df() or as_dataset_df().")
 
-  if("Subject" %in% names(attributes(x)))  {
-    attr(x, "Subject")
-  } else if(!is.null(dataset_bibentry(x)$subject)) {
-    as.character(dataset_bibentry(x)$subject)
+  if("subject" %in% names(attributes(x)))  {
+    attr(x, "subject")
+  } else if(!is.null(get_bibentry(x)$subject)) {
+    get_bibentry(x)$subject
   } else {
     message("No subject is recorded.")
   }
@@ -39,14 +55,15 @@ subject <- function(x) {
 #' Widely used namespaces (schemes) have conventional abbreviations.
 #' @param classificationCode The classificationCode subproperty may be used for
 #' subject schemes, like ANZSRC, which do not have valueURIs for each subject term.
-#' @return A named list with the subject term, the subject scheme, URIs and prefix.
+#' @return A \code{subject_create} returns a named list with the subject term,
+#' the subject scheme, URIs and prefix.
 #' @export
 subject_create <- function(term,
-                    schemeURI = NULL,
-                    valueURI = NULL,
-                    prefix = NULL,
-                    subjectScheme = NULL,
-                    classificationCode = NULL ) {
+                           schemeURI = NULL,
+                           valueURI = NULL,
+                           prefix = NULL,
+                           subjectScheme = NULL,
+                           classificationCode = NULL ) {
 
   if (is.null(term)) term <- ":tba"
 
@@ -55,7 +72,7 @@ subject_create <- function(term,
   #}
 
   if (length(term)>1) {
-    dataset_subject <-  lapply (1:length(term), function(x) new_Subject(term[x],
+    dataset_subject <-  lapply (1:seq_along(term), function(x) new_Subject(term[x],
                                                                 subjectScheme = subjectScheme[x],
                                                                 schemeURI = schemeURI[x],
                                                                 classificationCode = classificationCode[x],
@@ -105,47 +122,40 @@ new_Subject <- function(term,
                                prefix=prefix)
   }
 
-  class(dataset_subject ) <- c("subject", class(subject))
+  class(dataset_subject) <- c("subject", class(dataset_subject))
 
   dataset_subject
 }
 
 #' @rdname subject
-#' @param value A subject field created by \code{\link{subject}}.
-#' @param overwrite If the attributes should be overwritten. In case it is set to \code{FALSE},
-#' it gives a message with the current \code{Subject} property instead of overwriting it.
-#' Defaults to \code{FALSE}.
+#' @param value A subject field created by \code{\link{subject}}. The subject field
+#' is overwritten with this value.
 #' @export
-`subject<-` <- function(x, overwrite =FALSE, value) {
+`subject<-` <- function(x, value) {
 
-  if (is.character(value)) {
-    value <- list(term=value)
+  assert_that(is.dataset_df(x),
+              msg = "subject<-(x, value): x must be a dataset object created with dataset_df() or as_dataset_df().")
+
+  ds_bibentry <- get_bibentry(x)
+
+  if(is.null(value)) {
+    value <- new_Subject(term = ":tba")
+    } else if (is.character(value)) {
+    value <- new_Subject(term = value)
+  } else if (!is.subject(value)) {
+    stop("subject(x, value)<- : value must be a created with 'subject_create()` or it must be a character string.")
   }
 
-  if (is.null(value$subjectScheme)) value$subjectScheme <- ""
-  if (is.null(value$schemeURI)) value$schemeURI <- ""
-  if (is.null(value$valueURI)) value$valueURI <- ""
-  if (is.null(value$prefix)) value$prefix <- ""
-
-  if(!is.subject(value)) {
-    # it is a conforming list but not a subject class
-    dataset_subject <- subject_create(term = value$term,
-                                      schemeURI = value$schemeURI,
-                                      valueURI = value$valueURI,
-                                      prefix = value$prefix,
-                                      subjectScheme = value$subjectScheme,
-                                      classificationCode = value$classificationCode )
-  } else {
-   dataset_subject <- value
-  }
-
-
-  attr(x, "Subject") <- dataset_subject
-
+  ds_bibentry$subject <- value
+  ds_bibentry$subject
+  attr(x, "dataset_bibentry") <- ds_bibentry
+  attr(x, "subject") <- value
   invisible(x)
 }
 
 #' @rdname subject
+#' @return \code{is.subject} returns a logical value, \code{TRUE} if the subject as a list
+#' is well-formatted by \code{\link{subject_create}} with its necessary key-value pairs.
 is.subject <- function(x) {
   ifelse(inherits(x, "subject"), TRUE, FALSE)
 }
